@@ -94,6 +94,19 @@ class ChipmunkDb():
 
         return df
 
+    def collection_as_pandas_additional(self, collection, additionalCollections: [], columns=[], domain=None):
+        res = requests.get(url=self.getHostAndPort()+"/collection/"+collection+"/rawStream",
+                           headers={"Content-Type": 'application/octet-stream', "x-data": json.dumps({"columns": columns,
+                                                                                                      "additionalCollections": additionalCollections,
+                                                                                                      "domain": domain})})
+        data = res.content
+
+        pq_file = io.BytesIO(data)
+        df = pd.read_parquet(pq_file)
+
+        return df
+
+
 
 def main():
     print("Running")
\ No newline at end of file
